#define  USE_HY17P60_5M
/******************************************************************************
 * Demo.c                                                                                    *
 * -----------------------------------------------------------------------------------------*
 * Copyright 2020 HYCON Technology                                                *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17P60                                                           *
 ******************************************************************************/
 /*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <ADC.h>
#include <INT.h>
#include <CLK.h>
#include <PWR.h>
#include <RST.h>
#include <GPIO.h>
#include <LCD.h>
#include "display.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char ADCData,ADCData1,ADCData2;
unsigned char Flag;
long	ADCTemp;
volatile typedef union _MCUSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_TMBdone:1;
    unsigned b_TMCdone:1;
    unsigned b_Ext0done:1;
    unsigned b_Ext1done:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
  };
} MCUSTATUS;

MCUSTATUS  MCUSTATUSbits;

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void);
void ShowADC (void);
void Delay(unsigned int ms);
void DisplayNum(long Num);
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/

void main(void)
{
    SysInit();

	ADIF_ClearFlag();
	ADIE_Enable();
	GIE_Enable();
	DisplayHycon();
	Delay(60000);
	while(1)
	{
		if(MCUSTATUSbits.b_ADCdone==1)
		{
			MCUSTATUSbits.b_ADCdone=0;
			ADCTemp=ADCTemp>>6;
			ShowADC();
            Delay(20000);
	    }
    }
}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void)
{
//    CLK Setting    //
	CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_DHSCK);

//    GPIO Setting    //
    //TRISC6 = 0x00;
    //PT6 = 0x00;
    //PT6DA = 0x00;
    //PT6PU = 0xff;

    //TRISC7 = 0x00;
    //PT7 = 0x00;
    //PT7DA = 0x00;
    //PT7PU = 0xff;

    TRISC8 = 0x00;
    PT8 = 0x00;
    PT8IN = 0xff;
    PT8PU = 0xff;

//    VDDA Setting    //
    PWR_BGREnable();
    PWR_VDDAOpen(LDOC_2V4);
    Delay(1400);    //Delay 10ms

//    ADC Setting    //
    ADC_Open(DADC_DHSCKDIV4,SAD1FP_PB0,SAD1FN_PB2,SAD1RH_VDDA,SAD1RL_VSS,ADGN_1,
                       VREGN_DIV1,DCSET_P0,OSR_61440);
    ADC_VCMSSelect(VCMS_INTERNAL);
	ADC_ENACMEnable();
	ADC_ACMSource(VCINS_V12);

//    LCD Setting    //
	//LCDCN1 = 0xc9 ;
	LCD_Enable();
	LCD_VLCDSourceSelect(ENLCP_INTERNAL);
	LCD_ChargePumpSelect(LCDV_3V0);
	LCD_OutBufferEnable();
	LCD_ChargePumpClk(SELPCLK_14KHZ);
	LCD_DisplayOn();

 	//LCDCN3 = 0xff;
    LCD_COM0Mode(LCD);
    LCD_COM1Mode(LCD);
    LCD_COM2Mode(LCD);
    LCD_COM3Mode(LCD);

	//LCDCN4 = 0xff;
	LCD_PT80Mode(LCD);
	LCD_PT81Mode(LCD);
	LCD_PT82Mode(LCD);
	LCD_PT83Mode(LCD);
	LCD_PT84Mode(LCD);
	LCD_PT85Mode(LCD);
	LCD_PT86Mode(LCD);
	LCD_PT87Mode(LCD);

	//LCDCN6 = 0xff;
	LCD_PT64Mode(LCD);
	LCD_PT65Mode(LCD);
	LCD_PT66Mode(LCD);
	LCD_PT67Mode(LCD);

	//LCDCN7 = 0x00;
	LCD_PT70Mode(LCD);
	LCD_PT71Mode(LCD);
	LCD_PT72Mode(LCD);
	LCD_PT73Mode(LCD);

	//LCDCN8 = 0xff;
	LCD_PT74Mode(LCD);
	LCD_PT75Mode(LCD);
	LCD_PT76Mode(LCD);
	LCD_PT77Mode(LCD);


}
/*----------------------------------------------------------------------------*/
/*          LCD Show ADC                                                        */
/*----------------------------------------------------------------------------*/
void ShowADC (void)
{
	DisplayNum(ADCTemp);
}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int ms)
{
  for(;ms>0;ms--)
    NOP();
}
/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(ADIF_IsFlag())
	{
		ADIF_ClearFlag();
		ADCTemp=ADCR;
		MCUSTATUSbits.b_ADCdone=1;
	}
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
