#define  USE_HY17P60_5M
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <CLK.h>
#include <INT.h>
#include <ADC.h>
#include <PWR.h>
#include <GPIO.h>
#include <RST.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
//signed long
//range 8388607~-8388608 (dec)
//range 0x007F FFFF ~ 0xFF80 0000 (hex)
signed long  ADC_ISRTemp;
signed long  ADC_ISRTemp_Buffer[8];
unsigned int counter;

volatile typedef union _MCUSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_TMBdone:1;
    unsigned b_TMCdone:1;
    unsigned b_Ext0done:1;
    unsigned b_Ext1done:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
  };
} MCUSTATUS;

MCUSTATUS  MCUSTATUSbits;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
//void AccuracyModeADCOFF(void);
//void ADCAccuracyMode(void);
void SYSInit(void);
void Delay_NOP(unsigned long del);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    SYSInit();

    MCUSTATUSbits.b_ADCdone= 0;
    GIE_Enable();

    while(1)
    {

        if(MCUSTATUSbits.b_ADCdone== 1)
        {
            ADC_ISRTemp_Buffer[counter]=ADC_ISRTemp;
            MCUSTATUSbits.b_ADCdone= 0;
            counter++ ;
            if( counter== 8 )
            {
                counter= 0;
            }
        }
    }
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{

	if(ADC_INT_IsFlag())
	{
		ADC_INT_ClearFlag();
		ADC_ISRTemp=ADCR; //ADC_GetData();
		MCUSTATUSbits.b_ADCdone= 1;
	}
}

/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SYSInit(void)
{
	PWR_CSFONEnable();
	ENBOR2_Disable();
	PWR_CSFONDisable();

    // Clock Setting //
    CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_HSCK);
    CLK_DHSCKSelect(DHS_HSCKDIV1);    //ADC_CK=DHS_CK=HS_CK/1

    // VDDA Setting //
    PWR_VDDAOpen(LDOC_2V4);
    Delay_NOP(1000);      //Delay 10ms

    // ADC Setting //
    ADC_Open(DADC_DHSCKDIV4,SAD1FP_PB0,SAD1FN_PB2,SAD1RH_VDDA,SAD1RL_VSS,ADGN_1,
                       VREGN_DIV1,DCSET_P0,OSR_61440);

    ADC_VCMSSelect(VCMS_INTERNAL);   //Select ADC Common Voltage Source
                                                                      //INTERNAL=ACM,EXTERNAL=REFO
    // ACM setting
	ADC_ENACMEnable();
	ADC_ACMSource(VCINS_V12);    //VCINS_V12 or VCINS_VDDADIV2

	// REFO setting
	//PWR_REFOEnable();
	//PWR_REFOSource(SREFO_BGR);   //SREFO_BGR or SREFO_PB4

    //ADCAccuracyMode();
    //AccuracyModeADCOFF();
}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned long del)
{
    while(--del)
    __asm__ ("NOP") ;
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
