#define  USE_HY17P60_5M
/******************************************************************************
 * Frequency Counter.c                                                                                    *
 * -----------------------------------------------------------------------------------------*
 * Copyright 2020 HYCON Technology                                                *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17P60                                                           *
 ******************************************************************************/
 /*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <GPIO.h>
#include <PWR.h>
#include <WDT.h>

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned long CTAInitial,CTAFinal,CTBFinal,CTCFinal;
unsigned long k,T1,freq,duty;
unsigned long sysclk;

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void);
//void Delay(unsigned long del);
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    SysInit();

    PWR_FreqCountSource(ENCNTI_PCNTI);    //CNTI as Frequency Counter input source
    CTIE_Enable();

	GIE_Enable();



	while(1)
	{

        CTAInitial= 0xC00000;
        CTAU=  CTAInitial>> 16;
        CTAH= CTAInitial>> 8;
        CTAL=0;

        PWR_FreqCountEnable();    //Enable Frequency Counter

	    while(CTF_IsFlag()== 0);    //wait count finish
	    if(CTBOV_IsFlag()== 1)    //;CTB Over Flow
	        continue;

	    GIE_Disable();

        CTAFinal |= CTAU;
        CTAFinal<<= 8;
        CTAFinal |= CTAH;
        CTAFinal<<= 8;
        CTAFinal |= CTAL;

        CTBFinal |= CTBU;
        CTBFinal<<= 8;
        CTBFinal |= CTBH;
        CTBFinal<<= 8;
        CTBFinal |= CTBL;

        CTCFinal |= CTCU;
        CTCFinal<<= 8;
        CTCFinal |= CTCH;
        CTCFinal<<= 8;
        CTCFinal |= CTCL;

	    PWR_FreqCountDisable();
	    CTF_ClearFlag();
/*---------------------------------------------------------------------------------------------------*/
/*  T= (1000000h-CTA[23:0]Initial+CTA[23:0]Final)/SYSCLK                          */
/*  Freq= CTB[23:0]/T                                                                                       */
/*  Duty Cycle= CTC[23:0]/[1000000h-CTA[23:0]Initial + CTA[23:0]Final]       */
/*---------------------------------------------------------------------------------------------------*/
        k= 0x1000000;
        T1= k-CTAInitial;   //0x1000000-CTAInitial
        T1 += CTAFinal;

        sysclk= 0x4B0000;  //0x4B0000=4.9152MHz
        freq= (CTBFinal*sysclk)/T1;

        duty= CTCFinal*100;
        duty /= T1;       //unit: %

        while(1);
	}

}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{

}

/*-----------------------------------------------------------------------------*/
/*  Inital the System                                                                */
/*-----------------------------------------------------------------------------*/
void SysInit(void)
{
//    CLK Setting    //
    /* HAO=4.915M, DHS_CK=HS_CK/1, CPU_CK=DHS_CK*/
	CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_DHSCK);

//    GPIO Setting    //
    GPIO_PT3InputMode(6);
    GPIO_PT3SETIN(6);
    GPIO_PT3CLRPU(6);

//    BZ Setting    //
    BZ_CLKSource(BZS_LSCK);
    BZ_BZCKSelect(DBZ_DZCKDIV2);
    BZ_Enable();
}

/*---------------------------------------------------------------------------*/
/* End Of File                                                               */
/*---------------------------------------------------------------------------*/
