#define  USE_HY17P60_5M
/******************************************************************************
 * HY17P60_LVD.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2020 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *                                                                             *
 * For External Input                                                         *
 * IC Body: HY17P60                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <PWR.h>
#include <GPIO.h>
#include <RST.h>
#include <CLK.h>
#include <MFC.h>
#include <INT.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define MFC_Mode  0         //0=LVD, 1=Schmitt trigger


/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SYSInit(void);
void MFCInit(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{

    SYSInit();
    MFCInit();

	GPIO_PT1OutputMode(0);
	GPIO_PT1SETIN(0);
	GPIO_PT1CLR(0);

	while(1)
	{
	   if(MFC_OutputStatus() == 0)
	        GPIO_PT1CLR(0);
	    else
	        GPIO_PT1SET(0);
	}
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SYSInit(void)
{
	PWR_CSFONEnable();
	ENBOR2_Disable();
	PWR_CSFONDisable();
    PWR_BGREnable();
    // Clock Setting //
    CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_HSCK);

    // VDDA Setting //
    PWR_VDDAOpen(LDOC_2V4);
    Delay(1400);      //Delay 10ms
}

/*----------------------------------------------------------------------------*/
/* MFC Init Function                                                          */
/*----------------------------------------------------------------------------*/
void MFCInit(void)
{
/*---------------------------------------------------------------------------------------*/
/*    V=voltage sorce,X=CPDA[4:0]                                                    */
/*    22R5 short & 20R short => RLO=VDD*(X/32)                            */
/*    22R5 short & 20R open => RLO=VDD*((X+20)/(32+20))           */
/*    22R5 open & 20R short => RLO=VDD*(X/(32+22.5))                 */
/*    22R5 open & 20R open => RLO=VDD*((X+20)/(32+22.5+20))  */
/*----------------------------------------------------------------------------------------*/
#if (MFC_Mode == 0)   //LVD

//  LVD VDD Detect  //
    MFC_Open(CPPS_1V2,CPNS_RLO,CMPHS_NORMAL,CPOR_NORMAL);
    MFC_RLOSet(CPRH_VDD,CPRL2_VSS,CPRL1_SHORT,CPRL0_SHORT,CPDA_14DIV32);

//  LVD LVDIN Port Detect  //
    //MFC_Open(CPPS_LVDIN,CPNS_RLO,CMPHS_NORMAL,CPOR_NORMAL);
    //MFC_RLOSet(CPRH_VDDA,CPRL2_VSS,CPRL1_SHORT,CPRL0_SHORT,CPDA_24DIV32);


#else   //Schmitt trigger Mode

/*---------------------------------------------------------------------------------------*/
/*    VDDA=2.4V, 22R5 short, 20R short                                            */
/*    CPDA[4:0]=11000 -->RLO=1.8V                                                 */
/*    CPDA[4:0]=11100 -->RLO=2.1V                                                 */
/*    CPDM2 ENABLE                                                                         */
/*    MFCO=0 -->CPDA=11000                                                          */
/*    MFCO=1 -->CPDA=11100                                                          */
/*---------------------------------------------------------------------------------------*/
    MFC_Open(CPPS_PB0,CPNS_RLO,CMPHS_NORMAL,CPOR_INVERSE);
    MFC_RLOSet(CPRH_VDDA,CPRL2_VSS,CPRL1_SHORT,CPRL0_SHORT,CPDA_24DIV32);
    MFC_CPDM2Enable();

#endif

}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
