#define  USE_HY17P60_5M
/******************************************************************************
 * PWM.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2020 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                              *
 *   HY17P60                                                                  *
 * -----------                                                                           *
 *           |                                                                 *
 *     PT1.6 |-->PWM0                                                                          *
 *           |                                                                 *
 *     PT1.2 |-->PWM1                                                                      *
 *           |                                                                *
 * -----------                                                                           *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <TMR.h>
#include <CLK.h>
#include <INT.h>
#include <RST.h>
#include <GPIO.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define PWM_MODE 1
  #define PWM1O  1
  #define PWM2O  2
  #define PWM3O  3
  #define PWM4O  4
  #define PWM5O  5
  #define PWM6O  6
  #define PWM7O  7

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
//void Delay_NOP(unsigned int del);
void SysInit(void);
void PWMInit(void);

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    SysInit();
    PWMInit();
    GIE_Enable();

	while(1);

}
/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/* System Initial                                                                   */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
//    CLK Setting    //
    /* HAO=4.915M, DHS_CK=HS_CK/1, CPU_CK=DHS_CK*/
	CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_HSCK);

//    GPIO Setting    //
    GPIO_PT3OutputMode(5);
    GPIO_PT3SETIN(5);
    GPIO_PT3SETPU(5);
    GPIO_PT3CLR(5);

}

/*----------------------------------------------------------------------------*/
/* PWM Initial                                                                   */
/*----------------------------------------------------------------------------*/
void PWMInit(void)
{
/*--------------------------------------PWM1O-------------------------------------------*/
#if (PWM_MODE== PWM1O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM1O);		//PWM0 Output mode Select PWM1O
	TB1_PWM1ModeSelect(PWMA1_PWM1O);		//PWM1 Output mode Select PWM1O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0800);	// TB1C0[15:0] is setting the PWM frequency.
	TB1C1Set(0x0400);	// TB1C1[15:0] is setting the PWM Duty Cycle.

/*--------------------------------------PWM2O-------------------------------------------*/
#elif (PWM_MODE== PWM2O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM2O);		//PWM0 Output mode Select PWM2O
	TB1_PWM1ModeSelect(PWMA1_PWM2O);		//PWM1 Output mode Select PWM2O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0833);	//TB1C0[15:0] is setting the PWM frequency.
	TB1C2Set(0x01a4);	// TB1C2[15:0] is setting the PWM Duty Cycle.

/*--------------------------------------PWM3O-------------------------------------------*/
#elif (PWM_MODE== PWM3O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_2_8bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM3O);		//PWM0 Output mode Select PWM3O
	TB1_PWM1ModeSelect(PWMA1_PWM3O);		//PWM1 Output mode Select PWM3O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0029);	// TB1C0L[7:0] is setting the PWM frequency.
	TB1C1Set(0x0016);	// TB1C0L[7:0] is setting the PWM Duty Cycle.

/*--------------------------------------PWM4O-------------------------------------------*/
#elif (PWM_MODE== PWM4O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_2_8bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM4O);		//PWM0 Output mode Select PWM4O
	TB1_PWM1ModeSelect(PWMA1_PWM4O);		//PWM1 Output mode Select PWM4O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0xD100);	// TB1C0H[15:8] is setting the PWM frequency.
	TB1C2Set(0x0088);	// TB1C2L[7:0] is setting the PWM Duty Cycle.

/*--------------------------------------PWM5O-------------------------------------------*/
#elif (PWM_MODE== PWM5O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_8_8bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM5O);		//PWM0 Output mode Select PWM5O
	TB1_PWM1ModeSelect(PWMA1_PWM5O);		//PWM1 Output mode Select PWM5O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x00C8);	// TB1C0L[7:0] is setting the PWM frequency.
	TB1C1Set(0x0064);	// TB1C1L[7:0] is setting the PWM Duty Cycle.
	TB1C2Set(0x0080);	//	TB1C2L[7:0] is setting the PWM Duty Cycle fine tuning.

/*--------------------------------------PWM6O-------------------------------------------*/
#elif (PWM_MODE== PWM6O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_17bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM6O);		//PWM0 Output mode Select PWM6O
	TB1_PWM1ModeSelect(PWMA1_PWM6O);		//PWM1 Output mode Select PWM6O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x1000);	// TB1C0H[15:8] is setting the PWM frequency.
	TB1C1Set(0x0080);	// TB1C1L[7:0] is setting the PWM Duty Cycle.
	TB1C2Set(0x0A00);	//	TB1C2[15:0] is setting the PWM Duty Cycle
									// TB1C0 > TB1C2 > TB1C1

/*--------------------------------------PWM7O-------------------------------------------*/
#elif (PWM_MODE== PWM7O)
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	//TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_NORMAL);		//PWM1 Output Phase Normal

	//TB1_PWM0ModeSelect(PWMA0_PWM7O);		//PWM0 Output mode Select PWM7O
	TB1_PWM1ModeSelect(PWMA1_PWM7O);		//PWM1 Output mode Select PWM7O

	//TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x01F0);	// TB1C0[15:0] is setting the PWM frequency.
										// PWM Duty Cycle is always 50%
#endif

	TB1_ClearTMB1();	//TMB COUNT CLR
	TB1Enable();

}
/*----------------------------------------------------------------------------*/
/* End Of File                                       */
/*----------------------------------------------------------------------------*/

