#define  USE_HY17P60_5M
/******************************************************************************
 * RMS_Demo.c                                                                                    *
 * -----------------------------------------------------------------------------------------*
 * Copyright 2020 HYCON Technology                                                *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17P60                                                           *
 ******************************************************************************/
 /*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <ADC.h>
#include <INT.h>
#include <CLK.h>
#include <PWR.h>
#include <RST.h>
#include <GPIO.h>
#include <LCD.h>
#include <DSP.h>
#include "display.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char RMSMath[5];
long	ADCTemp,LPFTemp,RMSTemp;
volatile typedef union _ADCSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_LPFdone:1;
    unsigned b_RMSdone:1;
    unsigned b_CTFdone:1;
  };
} ADCSTATUS;

ADCSTATUS  ADCSTATUSbits;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void);
unsigned long SQRTcal (void);
void Delay (unsigned long ms);
//void DisplayNum(long Num);
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/

void main(void)
{
    SysInit();

	ADIF_ClearFlag();
	ADIE_Enable();
	GIE_Enable();
	DisplayHycon();
	Delay(60000);
	ClearLCD();

	while(1)
	{
		if(ADCSTATUSbits.b_ADCdone==1)
		{
			ADCSTATUSbits.b_ADCdone=0;
			/*ADCTemp=ADCTemp>>6;
			DisplayNum();
            Delay(20000);*/
	    }

		if(ADCSTATUSbits.b_LPFdone==1)
		{
			ADCSTATUSbits.b_LPFdone=0;
			/*LPFTemp=LPFTemp>>6;
			DisplayNum(ADCTemp);
            Delay(20000);*/
	    }

		if(ADCSTATUSbits.b_RMSdone==1)
		{
			GIE_Disable();
			ADCSTATUSbits.b_RMSdone=0;
            RMSTemp = SQRTcal();
			DisplayNum(RMSTemp);
            //Delay(20000);
            GIE_Enable();
	    }
    }
}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/* Setup System Function                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void)
{
//    Setup Clock    //
	CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV2,CPUS_DHSCK);

//    Setup GPIO     //
    //TRISC6 = 0x00;
    //PT6 = 0x00;
    //PT6DA = 0x00;
    //PT6PU = 0xff;

    //TRISC7 = 0x00;
    //PT7 = 0x00;
    //PT7DA = 0x00;
    //PT7PU = 0xff;

    TRISC8 = 0x00;
    PT8 = 0x00;
    PT8IN = 0xff;
    PT8PU = 0xff;

//    Setup IP Power    //
    PWR_BGREnable();
    PWR_VDDAOpen(LDOC_2V4);
    Delay(1000);    //Delay 10ms
    PWR_REFOEnable();
    PWR_VrefEnable();
    PWR_AGNDSelect(SAGND_3DIV10VDDA);

//    Setup ADC     //
    ADC_Open(DADC_DHSCKDIV8,SAD1FP_PB0,SAD1FN_PB2,SAD1RH_REFO,SAD1RL_VSS,ADGN_1,
                       VREGN_DIV1,DCSET_P0,OSR_32);

    ADC_VCMSSelect(VCMS_INTERNAL);
	ADC_ENACMEnable();
	ADC_ACMSource(VCINS_V12);

//    Setup LPF & RMS     //
	DSP_RMSEnable();
    DSP_LPFEnable();
    DSP_RMSData(ENSQRE_SQUARE);
    DSP_LPFOSR(LPFBW_512);
    DSP_FIREnable();
    PWR_SFT1Select(SFT1_100K);

    RMSIE_Enable();

//    Setup LCD     //
	//LCDCN1 = 0xc9 ;
	LCD_VLCDSourceSelect(ENLCP_INTERNAL);
	LCD_ChargePumpSelect(LCDV_3V0);
	LCD_OutBufferEnable();
	LCD_ChargePumpClk(SELPCLK_14KHZ);
	LCD_DisplayOn();
	LCD_Enable();

 	//LCDCN3 = 0xff;
    LCD_COM0Mode(LCD);
    LCD_COM1Mode(LCD);
    LCD_COM2Mode(LCD);
    LCD_COM3Mode(LCD);

	//LCDCN4 = 0xff;
	LCD_PT80Mode(LCD);
	LCD_PT81Mode(LCD);
	LCD_PT82Mode(LCD);
	LCD_PT83Mode(LCD);
	LCD_PT84Mode(LCD);
	LCD_PT85Mode(LCD);
	LCD_PT86Mode(LCD);
	LCD_PT87Mode(LCD);

	//LCDCN6 = 0xff;
	LCD_PT64Mode(LCD);
	LCD_PT65Mode(LCD);
	LCD_PT66Mode(LCD);
	LCD_PT67Mode(LCD);

	//LCDCN7 = 0x00;
	LCD_PT70Mode(LCD);
	LCD_PT71Mode(LCD);
	LCD_PT72Mode(LCD);
	LCD_PT73Mode(LCD);

	//LCDCN8 = 0xff;
	LCD_PT74Mode(LCD);
	LCD_PT75Mode(LCD);
	LCD_PT76Mode(LCD);
	LCD_PT77Mode(LCD);


}

/*----------------------------------------------------------------------------*/
/* SQRT Calculation Function                                               */
/*----------------------------------------------------------------------------*/
unsigned long SQRTcal(void)
{   unsigned char i;
    unsigned long Calculate,math,temp,k=0x100;

    for(i=0;i<= 20;i++)
    {
        math= RMSMath[4];
        math <<= 24;
        temp= math % k;
        math /= k;
        Calculate = math <<6;

        math= RMSMath[3];
        math <<= 22;
        math+= temp;
        temp= math % k;
        math /= k;
        Calculate += math;

        math= RMSMath[2];
        math <<= 14;
        math+= temp;
        temp= math % k;
        math /= k;
        Calculate += math;

        math= RMSMath[1];
        math <<= 6;
        math+= temp;
        temp= math % k;
        math /= k;
        Calculate += math;

        math= RMSMath[0];
        math+= temp;
        math /= k;
        Calculate+= math;

        Calculate+= k;
        Calculate >>=1;
        k= Calculate;
	}
    return Calculate;
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned long ms)
{
  for(;ms>0;ms--)
    NOP();
}
/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(ADIF_IsFlag())
	{
		ADIF_ClearFlag();
		ADCTemp=ADCR;
		ADCSTATUSbits.b_ADCdone=1;
	}
	if(LPFF_IsFlag())
	{
	    LPFF_ClearFlag();
        ((char *)(&LPFTemp))[0] = LPFDATAL;
        ((char *)(&LPFTemp))[1] = LPFDATAH;
        ((char *)(&LPFTemp))[2] = LPFDATAU;

        if (LPFTemp&0x800000L)
            ((char *)(&LPFTemp))[3] = 0xFF;
        else
            ((char *)(&LPFTemp))[3] = 0x00;
        ADCSTATUSbits.b_LPFdone=1;
	}

	if(RMSF_IsFlag())
	{
	    RMSF_ClearFlag();
        RMSMath[0] = RMSDATA0;
        RMSMath[1] = RMSDATA1;
        RMSMath[2] = RMSDATA2;
        RMSMath[3] = RMSDATA3;
        RMSMath[4] = RMSDATA4;
        ADCSTATUSbits.b_RMSdone=1;
	}
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
