#define  USE_HY17P60_5M
/******************************************************************************
 * TMR_Demo.c                                                                                    *
 * -----------------------------------------------------------------------------------------*
 * Copyright 2020 HYCON Technology                                                *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17P60                                                           *
 ******************************************************************************/
 /*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <GPIO.h>
#include <RST.h>
#include <TMR.h>
#include <WDT.h>

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char x=0;
unsigned char tmb_temp[10];
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define TMB_Mode 3
  #define mode_16bit 0
  #define mode_17bit 1
  #define mode_2_8bit 2
  #define mode_8_8bit 3

#define XOR 1
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit (void);
void TMRInit (void);
//void Delay(unsigned long del);
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    SysInit();
    TMRInit();

	GIE_Enable();


	while(1);

}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(TA1IF_IsFlag())       //TA1IF=1,TMA1R++
    {
        PT1 ^= (XOR <<0);
        TA1IF_ClearFlag();
    }

	if(TA1CIF_IsFlag())        //TMA1C=TMA1R ,then TA1CIF=1
    {
        PT1 ^= (XOR <<1);
        TMA1_ClearTMA1();        //clear TMA1R
        TA1CIF_ClearFlag();
	}

	if(TB1IF_IsFlag())
    {
        PT1 ^= (XOR <<2);
        TB1IF_ClearFlag();
    }
}

/*-----------------------------------------------------------------------------*/
/*  Inital the System                                                                */
/*-----------------------------------------------------------------------------*/
void SysInit(void)
{
//    CLK Setting    //
    /* HAO=4.915M, DHS_CK=HS_CK/1, CPU_CK=DHS_CK*/
	CLK_HAOOpen(HAOM_4915KHZ,DHS_HSCKDIV1,CPUS_HSCK);

//    GPIO Setting    //
    GPIO_PT1OutputMode(0);
    GPIO_PT1OutputMode(1);
    GPIO_PT1OutputMode(2);
    GPIO_PT1SETIN(0);
    GPIO_PT1SETIN(1);
    GPIO_PT1SETIN(2);
    GPIO_PT1CLR(0);
    GPIO_PT1CLR(1);
    GPIO_PT1CLR(2);
}

/*-----------------------------------------------------------------------------*/
/*  Inital TMA1 & TMB                                                            */
/*-----------------------------------------------------------------------------*/
void TMRInit(void)
{
//    TMA Setting    //
    /*TMA Interrupt trigger time=0.208ms~26.668ms, at clock source as DMS_CK,HAO=4.951MHz*/
    TMA1_Open(TMAS1_DMSCK,DTMA1_TMA1CKDIV2,4);
	TMA1Enable();

//    TMB Setting    //
/*TMB count time about 0.2us~1.6us, at clock source as HS_CK,HAO=4.951MHz*/
#if (TMB_Mode== mode_16bit)

	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_16bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count

#elif (TMB_Mode==mode_17bit)

	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_17bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count

#elif (TMB_Mode== mode_2_8bit)

	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_2_8bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count

#elif (TMB_Mode== mode_8_8bit)

	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_8_8bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count

#endif

	TB1Enable();

}

/*---------------------------------------------------------------------------*/
/* End Of File                                                               */
/*---------------------------------------------------------------------------*/
